# Inter-rater reliability, descriptives

setwd(dirname(rstudioapi::getActiveDocumentContext()$path))

library(ICC)

df = read.csv('../data/in1.csv', stringsAsFactors = TRUE)
sum(is.na(df$response))  # should be 0 NAs
# df = df[!is.na(df$response), ]

# Inter-rater reliability
iccs = data.frame(scale = levels(df$scale))
for (i in 1:nrow(iccs)) {
  iccs$ICC[i] = ICCest(sound, response, df[df$scale == iccs$scale[i], ])
}
iccs

#          scale       ICC
# 1    amusement 0.3971814
# 2      arousal 0.4616644
# 3 authenticity 0.2011496
# 4    contagion 0.2768461
# 5 pleasantness 0.1391175


# Or simple correlations b/w individual and aggregated responses
ag = aggregate(response ~ sound + scale, df, median)
ag$sound_scale = paste0(ag$sound, '_', ag$scale)
df$sound_scale = paste0(df$sound, '_', df$scale)
scales = levels(df$scale)

sumTab = data.frame(subject = unique(df$subject), cor = NA)
sumTab[, scales] = NA
for (i in 1:nrow(sumTab)) {
  temp = df[df$subject == sumTab$subject[i], ]
  for (s in scales) {
    temp_s = temp[temp$scale == s, ]
    if (nrow(temp_s) > 0) {
      idx = match(temp_s$sound_scale, ag$sound_scale)
      sumTab[i, s] = cor(temp_s$response, ag$response[idx], use = 'pairwise.complete.obs')
    }
  }
  idx = match(temp$sound_scale, ag$sound_scale)
  # plot(temp$response, ag$response[idx])
  sumTab$cor[i] = cor(temp$response, ag$response[idx], use = 'pairwise.complete.obs')
  sumTab$nTrials[i] = nrow(temp)
  sumTab$time[i] = max(as.numeric(temp$time), na.rm = TRUE) / 60000
}
summary(sumTab)
apply(sumTab[, c('cor', scales)], 2, function(x) median(x, na.rm = TRUE))


#       cor    amusement      arousal authenticity    contagion pleasantness 
# 0.6542915    0.7387506    0.8149166    0.5219516    0.6530280    0.5627712 


# Summary stats of participants
sumTab = data.frame(subject = unique(df$subject))
paste0(colnames(df), collapse = "','")
addVars = c('sex', 'age')
for (i in 1:nrow(sumTab)) {
  idx = which(df$subject == sumTab$subject[i])[1]
  sumTab[i, addVars] = df[idx, addVars]
}
sumTab
# write.csv(sumTab, '../data/participants_demographics.csv')
table(sumTab$sex)
# female   male 
#     55     45 
round(table(sumTab$sex) / nrow(sumTab) * 100, 0)
# female   male 
#     55     45 
hist(sumTab$age)
mean(sumTab$age); sd(sumTab$age); range(sumTab$age)
# [1] 24.19
# [1] 5.267961
# [1] 18 48



# correlations between scales
scales = levels(df$scale)
agCor = data.frame(sound = levels(df$sound))
for (i in 1:nrow(agCor)) {
  temp = df[df$sound == agCor$sound[i], ]
  for (s in scales) {
    agCor[i, s] = mean(temp$response[temp$scale == s])
  }
}
cor(agCor[, scales], use = 'pairwise.complete.obs')
#               amusement    arousal authenticity   contagion pleasantness
# amusement     1.0000000  0.7856054    0.5318003  0.71011012  -0.14535829
# arousal       0.7856054  1.0000000    0.4015256  0.71320419  -0.30297726
# authenticity  0.5318003  0.4015256    1.0000000  0.54463554   0.25914764
# contagion     0.7101101  0.7132042    0.5446355  1.00000000  -0.09569702
# pleasantness -0.1453583 -0.3029773    0.2591476 -0.09569702   1.00000000

