# preparation of the data from csv output of the experiment

setwd(dirname(rstudioapi::getActiveDocumentContext()$path))

folder_results = '../html/output'
folder_data = '../data/'

# Load results
files = list.files(folder_results, pattern = '*.csv')

out = vector('list', length(files))
for (i in 1:length(files)) {
  f = files[i]
  mydata = read.csv(paste0(folder_results, '/', f), header = FALSE, stringsAsFactors = FALSE)
  qn = as.character(mydata[1, 1:4])
  ratings = mydata[2:nrow(mydata), ]
  colnames(ratings) = c('subject', 'sound', 'time', 'RT', 'scale', 'response', 'clickTime', 'clickScore')
  ratings$csv = f
  ratings$sex = trimws(qn[3])
  ratings$age = trimws(qn[4])
  # head(ratings)
  out[[i]] = ratings
}
out = do.call(rbind, out)
out = out[!is.na(out$response), ]
head(out)
table(out$subject)
length(unique(out$sound))  # 21 * 3 * 2 = 126
table(out$sound)
nrow(out) / length(unique(out$sound)) / length(unique(out$scale))  # nrow(out) / 126 / 5 = 8.3 ratings per sound per scale (~.1 per participant)

# check for duplicates (glitches)
if (TRUE) {
  vars_to_check = c('subject', 'sound', 'response')
  d = which(duplicated(out[, vars_to_check]) | duplicated(out[, vars_to_check], fromLast = TRUE))  # if duplicates are found, we flag and remove all-but-one duplicated rows. See https://stackoverflow.com/questions/12495345/find-indices-of-duplicated-rows
  d
  if (length(d) > 0) {
    temp = out[d, ]
    temp$idx = d
    idx_rm = numeric(0)
    for (i in 2:nrow(temp)) {
      if (!any(temp[i - 1, vars_to_check] != temp[i, vars_to_check]))
        idx_rm = c(idx_rm, temp$idx[i])
    }
    out = out[-idx_rm, ]
  } 
}

## add info
for (i in 1:nrow(out)) {
  temp = as.character(out$sound[i])
  temp1 = unlist(strsplit(temp, '_'))
  out[i, c('sound_base', 'speakerSex', 'cond', 'dB')] = temp1
}
out$respNorm = out$response / 100
out$corpus = 'Anikin 2017'
length(unique(out$sound_base))  # 55
table(out$cond)
table(out$dB)
table(out$corpus)
table(out[unique(out$sound_base), ]$speakerSex)
table(out[unique(out$sound_base), ]$speakerSex, out[unique(out$sound_base), ]$corpus)
aggregate(respNorm ~ scale, out, range)
# boxplot(respNorm ~ scale, out)

## examine the consistency of answers and possibly remove weird participants
ag = aggregate(response ~ sound + scale, out, median)
ag$sound_scale = paste0(ag$sound, '_', ag$scale)

sumTab = data.frame(subject = unique(out$subject), cor = NA)
for (i in 1:nrow(sumTab)) {
  temp = out[out$subject == sumTab$subject[i], ]
  temp$sound_scale = paste0(temp$sound, '_', temp$scale)
  idx = match(temp$sound_scale, ag$sound_scale)
  sumTab$cor[i] = cor(temp$response, ag$response[idx], use = 'pairwise.complete.obs')
  sumTab$nTrials[i] = nrow(temp)
  sumTab$time[i] = max(as.numeric(temp$time), na.rm = TRUE) / 60000
}
sumTab = sumTab[order(sumTab$cor, decreasing = TRUE), ]
sumTab  

# exclude pp with very few trials and (optional) with weird responses
sumTab = sumTab[sumTab$nTrials > 20, ]
# hist(sumTab$cor[sumTab$nTrials > 20], breaks = 15)

median(sumTab$time)  # 10 min

sum(sumTab$cor < 0.2, na.rm = TRUE)  # 1

# idx_exclude = c()
# idx_include = which(sumTab$cor > .2)
# length(idx_include)  # 190
# length(unique(sumTab$subject))  # 202
# sumTab[-idx_include, ]  # maybe exclude these
# sum(!out$subject %in% sumTab$subject[idx_include]) / nrow(out)  # 6% of data

# save the dataset
out = out[out$subject %in% sumTab$subject, ]
out = out[, c('subject', 'sound', 'sound_base', 'corpus', 'speakerSex', 'dB', 'cond', 'time', 'RT', 'scale', 'response', 'clickTime', 'clickScore', 'respNorm', 'sex', 'age')]
# head(out)
# write.csv(out, '../data/inc.csv', row.names = FALSE)


# obs
df = read.csv('../data/inc.csv')
library(ggplot2)
df$cond = factor(df$cond, levels = c('orig', 'mix'))

ggplot(df, aes(dB, response, color = cond, shape = cond)) +
  geom_smooth(method = 'lm') +
  facet_wrap(~scale) +
  theme_bw()

ag = aggregate(response ~ cond + dB + scale, df, median)
ggplot(ag, aes(dB, response, color = cond, shape = cond)) +
  geom_line() +
  facet_wrap(~scale) +
  theme_bw()

summary(lm(response ~ cond * scale, out))
