setwd(dirname(rstudioapi::getActiveDocumentContext()$path))

library(ggplot2)
library(patchwork)


## Fitted values
fitted_laughs = readRDS('../../exp1_laughter/data/fitted.RDS')
fitted_cries = readRDS('../../exp2_crying/data/fitted.RDS')
fitted_moans = readRDS('../../exp3_moaning/data/fitted.RDS')
fitted_moans_pain = fitted_moans[fitted_moans$realEm == 'pain', ]
fitted_moans_pleasure = fitted_moans[fitted_moans$realEm == 'pleasure', ]

ylim = range(c(
  range(fitted_laughs[, c('lwr', 'upr')]),
  range(fitted_cries[, c('lwr', 'upr')]),
  range(fitted_moans[, c('lwr', 'upr')])
))

pl_laughs = ggplot(fitted_laughs, aes(x = dB, y = fit, ymin = lwr, ymax = upr, color = condFmt, linetype = condFmt, shape = condFmt, fill = condFmt, group = condFmt)) +
  geom_line(position = position_dodge(1)) +
  geom_point(size = 3, position = position_dodge(1)) +
  geom_errorbar(width = 0, linetype = 1, position = position_dodge(1)) +
  scale_color_manual(values = c('gray30', 'gray50')) +
  facet_wrap(~ scaleFmt, ncol = 5) +
  ylim(ylim) +  # ylim or ylim2 for the plot with separate moans of pain/pleasure
  xlab('') +
  ylab('') +
  ggtitle('A. Laughs') +
  theme_bw() +
  theme(panel.grid = element_blank(),
        legend.position = 'top',
        legend.title = element_blank())

pl_cries = ggplot(fitted_cries, aes(x = dB, y = fit, ymin = lwr, ymax = upr, color = condFmt, linetype = condFmt, shape = condFmt, fill = condFmt, group = condFmt)) +
  geom_line(position = position_dodge(1)) +
  geom_point(size = 3, position = position_dodge(1)) +
  geom_errorbar(width = 0, linetype = 1, position = position_dodge(1)) +
  scale_color_manual(values = c('gray30', 'gray50')) +
  facet_wrap(~ scaleFmt, ncol = 5) +
  ylim(ylim) +  # ylim or ylim2 for the plot with separate moans of pain/pleasure
  xlab('') +
  ylab('Rating, %') +
  ggtitle('B. Cries of sadness') +
  theme_bw() +
  theme(panel.grid = element_blank(),
        legend.position = 'top',
        legend.title = element_blank())

pl_moans_pain = ggplot(fitted_moans_pain, aes(x = dB, y = fit, ymin = lwr, ymax = upr, color = condFmt, linetype = condFmt, shape = condFmt, fill = condFmt, group = condFmt)) +
  geom_line(position = position_dodge(1)) +
  geom_point(size = 3, position = position_dodge(1)) +
  geom_errorbar(width = 0, linetype = 1, position = position_dodge(1)) +
  scale_color_manual(values = c('gray30', 'gray50')) +
  facet_wrap(~ scaleFmt, ncol = 5) +
  ylim(ylim) +
  xlab('') +
  ylab('') +
  ggtitle('C. Moans of pain') +
  theme_bw() +
  theme(panel.grid = element_blank(),
        legend.position = 'top',
        legend.title = element_blank())

pl_moans_pleasure = ggplot(fitted_moans_pleasure, aes(x = dB, y = fit, ymin = lwr, ymax = upr, color = condFmt, linetype = condFmt, shape = condFmt, fill = condFmt, group = condFmt)) +
  geom_line(position = position_dodge(1)) +
  geom_point(size = 3, position = position_dodge(1)) +
  geom_errorbar(width = 0, linetype = 1, position = position_dodge(1)) +
  scale_color_manual(values = c('gray30', 'gray50')) +
  facet_wrap(~ scaleFmt, ncol = 5) +
  ylim(ylim) +
  xlab('Attenuation of ingressive fragment, dB') +
  ylab('') +
  ggtitle('D. Moans of pleasure') +
  theme_bw() +
  theme(panel.grid = element_blank(),
        legend.position = 'top',
        legend.title = element_blank())

pl_laughs / pl_cries / pl_moans_pain / pl_moans_pleasure + 
  plot_layout(guides = 'collect') &
  theme(legend.position = 'top', 
        legend.margin = margin(-23, 0, 0, 0, unit = 'pt'),
        plot.margin = margin(1, 1, 0, 2, 'pt'))

# ggsave(filename = '../pix/fitted.png', width = 15, height = 18, units = 'cm', dpi = 600)


## Contrasts
contr_laughs = readRDS('../../exp1_laughter/data/contrasts_laughs.RDS')
contr_cries = readRDS('../../exp2_crying/data/contrasts_cries.RDS')
contr_moans = readRDS('../../exp3_moaning/data/contrasts_moans_realEm.RDS')
contr_moans_pain = contr_moans[contr_moans$realEm == 'pain', ]
contr_moans_pleasure = contr_moans[contr_moans$realEm == 'pleasure', ]

ylim = range(c(
  range(contr_laughs[, c('lwr', 'upr')]),
  range(contr_cries[, c('lwr', 'upr')]),
  range(contr_moans[, c('lwr', 'upr')])
))

pl_laughs = ggplot(contr_laughs, aes(x = dB, y = fit, ymin = lwr, ymax = upr, color = condFmt, linetype = condFmt, shape = condFmt, fill = condFmt, group = condFmt)) +
  geom_line(position = position_dodge(1)) +
  geom_point(size = 3, position = position_dodge(1)) +
  geom_errorbar(width = 0, linetype = 1, position = position_dodge(1)) +
  geom_hline(yintercept = 0, linetype = 3) +
  scale_color_manual(values = c('gray30', 'gray50')) +
  facet_wrap(~ scaleFmt, ncol = 5) +
  ylim(ylim) +  # ylim or ylim2 for the plot with separate moans of pain/pleasure
  xlab('') +
  ylab('') +
  ggtitle('A. Laughs') +
  theme_bw() +
  theme(panel.grid = element_blank(),
        legend.position = 'top',
        legend.title = element_blank())

pl_cries = ggplot(contr_cries, aes(x = dB, y = fit, ymin = lwr, ymax = upr, color = condFmt, linetype = condFmt, shape = condFmt, fill = condFmt, group = condFmt)) +
  geom_line(position = position_dodge(1)) +
  geom_point(size = 3, position = position_dodge(1)) +
  geom_errorbar(width = 0, linetype = 1, position = position_dodge(1)) +
  geom_hline(yintercept = 0, linetype = 3) +
  scale_color_manual(values = c('gray30', 'gray50')) +
  facet_wrap(~ scaleFmt, ncol = 5) +
  ylim(ylim) +  # ylim or ylim2 for the plot with separate moans of pain/pleasure
  xlab('') +
  ylab('Manipulation effect, %') +
  ggtitle('B. Cries of sadness') +
  theme_bw() +
  theme(panel.grid = element_blank(),
        legend.position = 'top',
        legend.title = element_blank())

pl_moans_pain = ggplot(contr_moans_pain, aes(x = dB, y = fit, ymin = lwr, ymax = upr, color = condFmt, linetype = condFmt, shape = condFmt, fill = condFmt, group = condFmt)) +
  geom_line(position = position_dodge(1)) +
  geom_point(size = 3, position = position_dodge(1)) +
  geom_errorbar(width = 0, linetype = 1, position = position_dodge(1)) +
  geom_hline(yintercept = 0, linetype = 3) +
  scale_color_manual(values = c('gray30', 'gray50')) +
  facet_wrap(~ scaleFmt, ncol = 5) +
  ylim(ylim) +
  xlab('') +
  ylab('') +
  ggtitle('C. Moans of pain') +
  theme_bw() +
  theme(panel.grid = element_blank(),
        legend.position = 'top',
        legend.title = element_blank())

pl_moans_pleasure = ggplot(contr_moans_pleasure, aes(x = dB, y = fit, ymin = lwr, ymax = upr, color = condFmt, linetype = condFmt, shape = condFmt, fill = condFmt, group = condFmt)) +
  geom_line(position = position_dodge(1)) +
  geom_point(size = 3, position = position_dodge(1)) +
  geom_errorbar(width = 0, linetype = 1, position = position_dodge(1)) +
  geom_hline(yintercept = 0, linetype = 3) +
  scale_color_manual(values = c('gray30', 'gray50')) +
  facet_wrap(~ scaleFmt, ncol = 5) +
  ylim(ylim) +
  xlab('Attenuation of ingressive fragment, dB') +
  ylab('') +
  ggtitle('D. Moans of pleasure') +
  theme_bw() +
  theme(panel.grid = element_blank(),
        legend.position = 'top',
        legend.title = element_blank())

pl_laughs / pl_cries / pl_moans_pain / pl_moans_pleasure + 
  plot_layout(guides = 'collect') &
  theme(legend.position = 'top', 
        legend.margin = margin(-23, 0, 0, 0, unit = 'pt'),
        plot.margin = margin(1, 1, 0, 2, 'pt'))

# ggsave(filename = '../pix/contrasts.png', width = 15, height = 18, units = 'cm', dpi = 600)


