# Inter-rater reliability, descriptives

setwd(dirname(rstudioapi::getActiveDocumentContext()$path))

library(ICC)

df = read.csv('../data/inm.csv', stringsAsFactors = TRUE)
sum(is.na(df$response))  # should be 0 NAs
# df = df[!is.na(df$response), ]

# Inter-rater reliability
iccs = data.frame(scale = levels(df$scale))
for (i in 1:nrow(iccs)) {
  iccs$ICC[i] = ICCest(sound, response, df[df$scale == iccs$scale[i], ])
}
iccs

#          scale        ICC
# 1      valence  0.5976547
# 2      arousal  0.2602317
# 3    contagion 0.09969293
# 4   disturbing  0.1526863
# 5 authenticity 0.05568608


# Or simple correlations b/w individual and aggregated responses
ag = aggregate(response ~ sound + scale, df, median)
ag$sound_scale = paste0(ag$sound, '_', ag$scale)
df$sound_scale = paste0(df$sound, '_', df$scale)
scales = levels(df$scale)

sumTab = data.frame(subject = unique(df$subject), cor = NA)
sumTab[, scales] = NA
for (i in 1:nrow(sumTab)) {
  temp = df[df$subject == sumTab$subject[i], ]
  for (s in scales) {
    temp_s = temp[temp$scale == s, ]
    if (nrow(temp_s) > 0) {
      idx = match(temp_s$sound_scale, ag$sound_scale)
      sumTab[i, s] = cor(temp_s$response, ag$response[idx], use = 'pairwise.complete.obs')
    }
  }
  idx = match(temp$sound_scale, ag$sound_scale)
  # plot(temp$response, ag$response[idx])
  sumTab$cor[i] = cor(temp$response, ag$response[idx], use = 'pairwise.complete.obs')
  sumTab$nTrials[i] = nrow(temp)
  sumTab$time[i] = max(as.numeric(temp$time), na.rm = TRUE) / 60000
}
summary(sumTab)
apply(sumTab[, c('cor', scales)], 2, function(x) median(x, na.rm = TRUE))

   #       cor      valence      arousal    contagion   disturbing authenticity 
   # 0.6293199    0.8468769    0.6440658    0.5248599    0.6177695    0.3877196 


# Summary stats of participants
sumTab = data.frame(subject = unique(df$subject))
paste0(colnames(df), collapse = "','")
addVars = c('sex', 'age')
for (i in 1:nrow(sumTab)) {
  idx = which(df$subject == sumTab$subject[i])[1]
  sumTab[i, addVars] = df[idx, addVars]
}
sumTab
# write.csv(sumTab, '../data/participants_demographics.csv')
table(sumTab$sex)
# female   male 
#     54     47 
round(table(sumTab$sex) / nrow(sumTab) * 100, 0)
# female   male 
#     53     47 
hist(sumTab$age)
mean(sumTab$age); sd(sumTab$age); range(sumTab$age)
# [1] 23.9901
# [1] 4.924419
# [1] 18 42


## demographics in all 3 experiments
info_laughs = read.csv('../../exp1_laughter/data/participants_demographics.csv')
info_cries = read.csv('../../exp2_crying/data/participants_demographics.csv')
info_moans = read.csv('../../exp3_moaning/data/participants_demographics.csv')

sumTab = rbind(info_laughs, info_cries, info_moans)
table(sumTab$sex)
# female   male  other 
#    157    123      3 
round(table(sumTab$sex) / nrow(sumTab) * 100, 0)
# female   male  other 
#     55     43      1 
hist(sumTab$age)
mean(sumTab$age); sd(sumTab$age); range(sumTab$age)
# [1] 24.41696
# [1] 5.860917
# [1] 18 59


# correlations between scales
scales = levels(df$scale)
agCor = data.frame(sound = levels(df$sound))
for (i in 1:nrow(agCor)) {
  temp = df[df$sound == agCor$sound[i], ]
  for (s in scales) {
    agCor[i, s] = mean(temp$response[temp$scale == s])
  }
}
cor(agCor[, scales], use = 'pairwise.complete.obs')
#                 valence    arousal  contagion disturbing authenticity
# valence       1.0000000 -0.4395998  0.4839860 -0.5985239    0.2649130
# arousal      -0.4395998  1.0000000 -0.1403010  0.5686753   -0.3191110
# contagion     0.4839860 -0.1403010  1.0000000 -0.3059730    0.1725277
# disturbing   -0.5985239  0.5686753 -0.3059730  1.0000000   -0.2908355
# authenticity  0.2649130 -0.3191110  0.1725277 -0.2908355    1.0000000

